@@ -1,4 +1,5 @@
 from os import path as op
+import inspect
 
 from amalgam.backends.sqla.base import Base
 from svarga import env
@@ -81,28 +82,25 @@ def instrument(name):
 
     # Find at least one model which belongs to this module
     model = None
-
-    for n in dir(module):
-        obj = getattr(module, n)
+    for n, obj in inspect.getmembers(module):
         try:
             if obj.__module__ == module.__name__ and issubclass(obj, Base):
                 model = obj
                 break
-        except TypeError:
+        except (TypeError, AttributeError):
             pass
-
     if model is None:
         # TODO: Error logging
         return None
 
     # Now, try to find base class
     base = None
-
-    for n in dir(module):
-        obj = getattr(module, n)
+    for n, obj in inspect.getmembers(module):
         if model is not obj and isinstance(obj, type) and issubclass(model, obj):
             base = n
             break
+    if base is None:
+        return None
 
     content = files.read_template('migrate.py_tmpl')
 
